@@ -2,13 +2,11 @@
 
 SYS_FUNC(fstatfs64)
 {
-	const unsigned long size = tcp->u_arg[1];
-
 	if (entering(tcp)) {
 		printfd(tcp, tcp->u_arg[0]);
-		tprintf(", %lu, ", size);
+		tprintf(", %" PRI_klu ", ", tcp->u_arg[1]);
 	} else {
-		print_struct_statfs64(tcp, tcp->u_arg[2], size);
+		print_struct_statfs64(tcp, tcp->u_arg[2], tcp->u_arg[1]);
 	}
 	return 0;
 }
