@@ -7,7 +7,7 @@ SYS_FUNC(getcwd)
 			printaddr(tcp->u_arg[0]);
 		else
 			printpathn(tcp, tcp->u_arg[0], tcp->u_rval - 1);
-		tprintf(", %lu", tcp->u_arg[1]);
+		tprintf(", %" PRI_klu, tcp->u_arg[1]);
 	}
 	return 0;
 }
