@@ -177,20 +177,20 @@
 [169] = { 2,	0,		SEN(gettimeofday),		"gettimeofday"		},
 [170] = { 2,	0,		SEN(settimeofday),		"settimeofday"		},
 [171] = { 1,	0,		SEN(adjtimex),			"adjtimex"		},
-[172] = { 0,	NF,		SEN(getpid),			"getpid"		},
-[173] = { 0,	NF,		SEN(getppid),			"getppid"		},
-[174] = { 0,	NF,		SEN(getuid),			"getuid"		},
-[175] = { 0,	NF,		SEN(geteuid),			"geteuid"		},
-[176] = { 0,	NF,		SEN(getgid),			"getgid"		},
-[177] = { 0,	NF,		SEN(getegid),			"getegid"		},
-[178] = { 0,	NF,		SEN(gettid),			"gettid"		},
+[172] = { 0,	PU|NF,		SEN(getpid),			"getpid"		},
+[173] = { 0,	PU|NF,		SEN(getppid),			"getppid"		},
+[174] = { 0,	PU|NF,		SEN(getuid),			"getuid"		},
+[175] = { 0,	PU|NF,		SEN(geteuid),			"geteuid"		},
+[176] = { 0,	PU|NF,		SEN(getgid),			"getgid"		},
+[177] = { 0,	PU|NF,		SEN(getegid),			"getegid"		},
+[178] = { 0,	PU|NF,		SEN(gettid),			"gettid"		},
 [179] = { 1,	0,		SEN(sysinfo),			"sysinfo"		},
-[180] = { 4,	0,		SEN(mq_open),			"mq_open"		},
+[180] = { 4,	TD,		SEN(mq_open),			"mq_open"		},
 [181] = { 1,	0,		SEN(mq_unlink),			"mq_unlink"		},
-[182] = { 5,	0,		SEN(mq_timedsend),		"mq_timedsend"		},
-[183] = { 5,	0,		SEN(mq_timedreceive),		"mq_timedreceive"	},
-[184] = { 2,	0,		SEN(mq_notify),			"mq_notify"		},
-[185] = { 3,	0,		SEN(mq_getsetattr),		"mq_getsetattr"		},
+[182] = { 5,	TD,		SEN(mq_timedsend),		"mq_timedsend"		},
+[183] = { 5,	TD,		SEN(mq_timedreceive),		"mq_timedreceive"	},
+[184] = { 2,	TD,		SEN(mq_notify),			"mq_notify"		},
+[185] = { 3,	TD,		SEN(mq_getsetattr),		"mq_getsetattr"		},
 [186] = { 2,	TI,		SEN(msgget),			"msgget"		},
 [187] = { 3,	TI,		SEN(msgctl),			"msgctl"		},
 [188] = { 5,	TI,		SEN(msgrcv),			"msgrcv"		},
