@@ -7,7 +7,7 @@
  */
 
 static int
-arch_set_scno(struct tcb *tcp, long scno)
+arch_set_scno(struct tcb *tcp, kernel_ulong_t scno)
 {
 	unsigned int n = (uint16_t) scno;
 	const struct iovec io = {
