@@ -1,6 +1,6 @@
 /*
  * Copyright (c) 2004-2009 Atmel Corporation
- * Copyright (c) 2009-2017 The strace developers.
+ * Copyright (c) 2009-2018 The strace developers.
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -46,11 +46,11 @@
 [ 17] = { 3,	TF,		SEN(chown),			"lchown"		},
 [ 18] = { 3,	TD,		SEN(lseek),			"lseek"			},
 [ 19] = { 5,	TD,		SEN(llseek),			"_llseek"		},
-[ 20] = { 0,	NF,		SEN(getpid),			"getpid"		},
+[ 20] = { 0,	PU|NF,		SEN(getpid),			"getpid"		},
 [ 21] = { 5,	TF,		SEN(mount),			"mount"			},
 [ 22] = { 1,	TF,		SEN(umount2),			"umount2"		},
 [ 23] = { 1,	0,		SEN(setuid),			"setuid"		},
-[ 24] = { 0,	NF,		SEN(getuid),			"getuid"		},
+[ 24] = { 0,	PU|NF,		SEN(getuid),			"getuid"		},
 [ 25] = { 1,	0,		SEN(stime),			"stime"			},
 [ 26] = { 4,	0,		SEN(ptrace),			"ptrace"		},
 [ 27] = { 1,	0,		SEN(alarm),			"alarm"			},
@@ -73,10 +73,10 @@
 [ 44] = { 5,	TP,		SEN(clone),			"clone"			},
 [ 45] = { 1,	TM|SI,		SEN(brk),			"brk"			},
 [ 46] = { 1,	0,		SEN(setgid),			"setgid"		},
-[ 47] = { 0,	NF,		SEN(getgid),			"getgid"		},
+[ 47] = { 0,	PU|NF,		SEN(getgid),			"getgid"		},
 [ 48] = { 2,	TF,		SEN(getcwd),			"getcwd"		},
-[ 49] = { 0,	NF,		SEN(geteuid),			"geteuid"		},
-[ 50] = { 0,	NF,		SEN(getegid),			"getegid"		},
+[ 49] = { 0,	PU|NF,		SEN(geteuid),			"geteuid"		},
+[ 50] = { 0,	PU|NF,		SEN(getegid),			"getegid"		},
 [ 51] = { 1,	TF,		SEN(acct),			"acct"			},
 [ 52] = { 1,	NF,		SEN(setfsuid),			"setfsuid"		},
 [ 53] = { 1,	NF,		SEN(setfsgid),			"setfsgid"		},
@@ -90,8 +90,8 @@
 [ 61] = { 2,	0,		SEN(setregid),			"setregid"		},
 [ 62] = { 2,	TSFA,		SEN(ustat),			"ustat"			},
 [ 63] = { 2,	TD,		SEN(dup2),			"dup2"			},
-[ 64] = { 0,	NF,		SEN(getppid),			"getppid"		},
-[ 65] = { 0,	0,		SEN(getpgrp),			"getpgrp"		},
+[ 64] = { 0,	PU|NF,		SEN(getppid),			"getppid"		},
+[ 65] = { 0,	PU|NF,		SEN(getpgrp),			"getpgrp"		},
 [ 66] = { 0,	0,		SEN(setsid),			"setsid"		},
 [ 67] = { 4,	TS,		SEN(rt_sigaction),		"rt_sigaction"		},
 [ 68] = { 0,	TS,		SEN(rt_sigreturn),		"rt_sigreturn"		},
@@ -202,7 +202,7 @@
 [173] = { 3,	TM,		SEN(madvise),			"madvise"		},
 [174] = { 3,	TD,		SEN(getdents64),		"getdents64"		},
 [175] = { 3,	TD,		SEN(fcntl64),			"fcntl64"		},
-[176] = { 0,	NF,		SEN(gettid),			"gettid"		},
+[176] = { 0,	PU|NF,		SEN(gettid),			"gettid"		},
 [177] = { 4,	TD,		SEN(readahead),			"readahead"		},
 [178] = { 5,	TF,		SEN(setxattr),			"setxattr"		},
 [179] = { 5,	TF,		SEN(setxattr),			"lsetxattr"		},
@@ -253,12 +253,12 @@
 [224] = { 6,	TD,		SEN(fadvise64_64),		"fadvise64_64"		},
 [225] = { 3,	0,		SEN(printargs),			"cacheflush"		},
 [226] = { 5,	0,		SEN(vserver),			"vserver"		},
-[227] = { 4,	0,		SEN(mq_open),			"mq_open"		},
+[227] = { 4,	TD,		SEN(mq_open),			"mq_open"		},
 [228] = { 1,	0,		SEN(mq_unlink),			"mq_unlink"		},
-[229] = { 5,	0,		SEN(mq_timedsend),		"mq_timedsend"		},
-[230] = { 5,	0,		SEN(mq_timedreceive),		"mq_timedreceive"	},
-[231] = { 2,	0,		SEN(mq_notify),			"mq_notify"		},
-[232] = { 3,	0,		SEN(mq_getsetattr),		"mq_getsetattr"		},
+[229] = { 5,	TD,		SEN(mq_timedsend),		"mq_timedsend"		},
+[230] = { 5,	TD,		SEN(mq_timedreceive),		"mq_timedreceive"	},
+[231] = { 2,	TD,		SEN(mq_notify),			"mq_notify"		},
+[232] = { 3,	TD,		SEN(mq_getsetattr),		"mq_getsetattr"		},
 [233] = { 4,	0,		SEN(kexec_load),		"kexec_load"		},
 [234] = { 5,	TP,		SEN(waitid),			"waitid"		},
 [235] = { 5,	0,		SEN(add_key),			"add_key"		},
