@@ -1,2 +1,2 @@
-static long hppa_r28;
+static unsigned long hppa_r28;
 #define ARCH_PC_PEEK_ADDR PT_IAOQ0
