@@ -1,13 +1,13 @@
 static void
 arch_sigreturn(struct tcb *tcp)
 {
-	long addr;
+	unsigned long addr;
 
 	/* Fetch pointer to struct sigcontext.  */
 	if (umove(tcp, *m68k_usp_ptr + 2 * sizeof(int), &addr) < 0)
 		return;
 
-	unsigned long mask[NSIG / 8 / sizeof(long)];
+	unsigned long mask[NSIG_BYTES / sizeof(long)];
 	/* Fetch first word of signal mask.  */
 	if (umove(tcp, addr, &mask[0]) < 0)
 		return;
