@@ -6,7 +6,7 @@ get_syscall_args(struct tcb *tcp)
 
 	for (i = 0; i < MAX_ARGS; i++) {
 		/* arguments go backwards from D1Ar1 (D1.3) */
-		tcp->u_arg[i] = ((unsigned long *)&metag_regs.dx[3][1])[-i];
+		tcp->u_arg[i] = (&metag_regs.dx[3][1])[-i];
 	}
 	return 1;
 }
