@@ -1,5 +1,5 @@
 static int
 arch_set_scno(struct tcb *tcp, kernel_ulong_t scno)
 {
-	return upoke(tcp->pid, 0, scno);
+	return upoke(tcp, 0, scno);
 }
