@@ -230,12 +230,12 @@
 [5227] = { 6,	TM,		SEN(mbind),			"mbind"			},
 [5228] = { 5,	TM,		SEN(get_mempolicy),		"get_mempolicy"		},
 [5229] = { 3,	TM,		SEN(set_mempolicy),		"set_mempolicy"		},
-[5230] = { 4,	0,		SEN(mq_open),			"mq_open"		},
+[5230] = { 4,	TD,		SEN(mq_open),			"mq_open"		},
 [5231] = { 1,	0,		SEN(mq_unlink),			"mq_unlink"		},
-[5232] = { 5,	0,		SEN(mq_timedsend),		"mq_timedsend"		},
-[5233] = { 5,	0,		SEN(mq_timedreceive),		"mq_timedreceive"	},
-[5234] = { 2,	0,		SEN(mq_notify),			"mq_notify"		},
-[5235] = { 3,	0,		SEN(mq_getsetattr),		"mq_getsetattr"		},
+[5232] = { 5,	TD,		SEN(mq_timedsend),		"mq_timedsend"		},
+[5233] = { 5,	TD,		SEN(mq_timedreceive),		"mq_timedreceive"	},
+[5234] = { 2,	TD,		SEN(mq_notify),			"mq_notify"		},
+[5235] = { 3,	TD,		SEN(mq_getsetattr),		"mq_getsetattr"		},
 [5236] = { 5,	0,		SEN(vserver),			"vserver"		},
 [5237] = { 5,	TP,		SEN(waitid),			"waitid"		},
 [5238] = { },
