@@ -18,11 +18,11 @@
 [ 17] = { 1,	TM|SI,		SEN(brk),			"brk"			},
 [ 18] = { 4,	0,		SEN(printargs),			"perfctr"		},
 [ 19] = { 3,	TD,		SEN(lseek),			"lseek"			},
-[ 20] = { 0,	NF,		SEN(getpid),			"getpid"		},
+[ 20] = { 0,	PU|NF,		SEN(getpid),			"getpid"		},
 [ 21] = { 2,	0,		SEN(capget),			"capget"		},
 [ 22] = { 2,	0,		SEN(capset),			"capset"		},
 [ 23] = { 1,	0,		SEN(setuid),			"setuid"		},
-[ 24] = { 0,	NF,		SEN(getuid),			"getuid"		},
+[ 24] = { 0,	PU|NF,		SEN(getuid),			"getuid"		},
 [ 25] = { 4,	TD,		SEN(vmsplice),			"vmsplice"		},
 [ 26] = { 4,	0,		SEN(ptrace),			"ptrace"		},
 [ 27] = { 1,	0,		SEN(alarm),			"alarm"			},
@@ -44,10 +44,10 @@
 [ 44] = { },
 [ 45] = { 2,	TF,		SEN(umount2),			"umount2"		},
 [ 46] = { 1,	0,		SEN(setgid),			"setgid"		},
-[ 47] = { 0,	NF,		SEN(getgid),			"getgid"		},
+[ 47] = { 0,	PU|NF,		SEN(getgid),			"getgid"		},
 [ 48] = { 2,	TS,		SEN(signal),			"signal"		},
-[ 49] = { 0,	NF,		SEN(geteuid),			"geteuid"		},
-[ 50] = { 0,	NF,		SEN(getegid),			"getegid"		},
+[ 49] = { 0,	PU|NF,		SEN(geteuid),			"geteuid"		},
+[ 50] = { 0,	PU|NF,		SEN(getegid),			"getegid"		},
 [ 51] = { 1,	TF,		SEN(acct),			"acct"			},
 [ 52] = { 2,	0,		SEN(printargs),			"memory_ordering"	},
 [ 53] = { },
@@ -61,7 +61,7 @@
 [ 61] = { 1,	TF,		SEN(chroot),			"chroot"		},
 [ 62] = { 2,	TD|TFST|TSTA,	SEN(fstat),			"fstat"			},
 [ 63] = { 2,	TD|TFST|TSTA,	SEN(fstat64),			"fstat64"		},
-[ 64] = { 0,	0,		SEN(getpagesize),		"getpagesize"		},
+[ 64] = { 0,	PU|NF,		SEN(getpagesize),		"getpagesize"		},
 [ 65] = { 3,	TM,		SEN(msync),			"msync"			},
 [ 66] = { 0,	TP,		SEN(vfork),			"vfork"			},
 [ 67] = { 4,	TD,		SEN(pread),			"pread64"		},
@@ -77,7 +77,7 @@
 [ 78] = { 3,	TM,		SEN(mincore),			"mincore"		},
 [ 79] = { 2,	0,		SEN(getgroups),			"getgroups"		},
 [ 80] = { 2,	0,		SEN(setgroups),			"setgroups"		},
-[ 81] = { 0,	0,		SEN(getpgrp),			"getpgrp"		},
+[ 81] = { 0,	PU|NF,		SEN(getpgrp),			"getpgrp"		},
 [ 82] = { },
 [ 83] = { 3,	0,		SEN(setitimer),			"setitimer"		},
 [ 84] = { },
@@ -139,7 +139,7 @@
 [140] = { 4,	TD|TN,		SEN(sendfile64),		"sendfile64"		},
 [141] = { 3,	TN,		SEN(getpeername),		"getpeername"		},
 [142] = { 6,	0,		SEN(futex),			"futex"			},
-[143] = { 0,	NF,		SEN(gettid),			"gettid"		},
+[143] = { 0,	PU|NF,		SEN(gettid),			"gettid"		},
 [144] = { 2,	0,		SEN(getrlimit),			"getrlimit"		},
 [145] = { 2,	0,		SEN(setrlimit),			"setrlimit"		},
 [146] = { 2,	TF,		SEN(pivotroot),			"pivot_root"		},
@@ -193,7 +193,7 @@
 [194] = { 4,	TD,		SEN(epoll_ctl),			"epoll_ctl"		},
 [195] = { 4,	TD,		SEN(epoll_wait),		"epoll_wait"		},
 [196] = { 3,	0,		SEN(ioprio_set),		"ioprio_set"		},
-[197] = { 0,	NF,		SEN(getppid),			"getppid"		},
+[197] = { 0,	PU|NF,		SEN(getppid),			"getppid"		},
 [198] = { 3,	TS,		SEN(sigaction),			"sigaction"		},
 [199] = { 0,	TS,		SEN(sgetmask),			"sgetmask"		},
 [200] = { 1,	TS,		SEN(ssetmask),			"ssetmask"		},
@@ -269,12 +269,12 @@
 [270] = { 3,	0,		SEN(io_submit),			"io_submit"		},
 [271] = { 3,	0,		SEN(io_cancel),			"io_cancel"		},
 [272] = { 5,	0,		SEN(io_getevents),		"io_getevents"		},
-[273] = { 4,	0,		SEN(mq_open),			"mq_open"		},
+[273] = { 4,	TD,		SEN(mq_open),			"mq_open"		},
 [274] = { 1,	0,		SEN(mq_unlink),			"mq_unlink"		},
-[275] = { 5,	0,		SEN(mq_timedsend),		"mq_timedsend"		},
-[276] = { 5,	0,		SEN(mq_timedreceive),		"mq_timedreceive"	},
-[277] = { 2,	0,		SEN(mq_notify),			"mq_notify"		},
-[278] = { 3,	0,		SEN(mq_getsetattr),		"mq_getsetattr"		},
+[275] = { 5,	TD,		SEN(mq_timedsend),		"mq_timedsend"		},
+[276] = { 5,	TD,		SEN(mq_timedreceive),		"mq_timedreceive"	},
+[277] = { 2,	TD,		SEN(mq_notify),			"mq_notify"		},
+[278] = { 3,	TD,		SEN(mq_getsetattr),		"mq_getsetattr"		},
 [279] = { 5,	TP,		SEN(waitid),			"waitid"		},
 [280] = { 4,	TD,		SEN(tee),			"tee"			},
 [281] = { 5,	0,		SEN(add_key),			"add_key"		},
@@ -336,7 +336,7 @@
 [337] = { 2,	TD,		SEN(setns),			"setns"			},
 [338] = { 6,	0,		SEN(process_vm_readv),		"process_vm_readv"	},
 [339] = { 6,	0,		SEN(process_vm_writev),		"process_vm_writev"	},
-[340] = { 0,	NF,		SEN(printargs),			"kern_features"		},
+[340] = { 0,	PU|NF,		SEN(printargs),			"kern_features"		},
 [341] = { 5,	0,		SEN(kcmp),			"kcmp"			},
 [342] = { 3,	TD,		SEN(finit_module),		"finit_module"		},
 [343] = { 3,	0,		SEN(sched_setattr),		"sched_setattr"		},
