@@ -37,7 +37,7 @@
 [ 36] = { 2,	0,		SEN(getitimer),			"getitimer"		},
 [ 37] = { 1,	0,		SEN(alarm),			"alarm"			},
 [ 38] = { 3,	0,		SEN(setitimer),			"setitimer"		},
-[ 39] = { 0,	NF,		SEN(getpid),			"getpid"		},
+[ 39] = { 0,	PU|NF,		SEN(getpid),			"getpid"		},
 [ 40] = { 4,	TD|TN,		SEN(sendfile64),		"sendfile"		},
 [ 41] = { 3,	TN,		SEN(socket),			"socket"		},
 [ 42] = { 3,	TN,		SEN(connect),			"connect"		},
@@ -100,16 +100,16 @@
 [ 99] = { 1,	0,		SEN(sysinfo),			"sysinfo"		},
 [100] = { 1,	0,		SEN(times),			"times"			},
 [101] = { 4,	0,		SEN(ptrace),			"ptrace"		},
-[102] = { 0,	NF,		SEN(getuid),			"getuid"		},
+[102] = { 0,	PU|NF,		SEN(getuid),			"getuid"		},
 [103] = { 3,	0,		SEN(syslog),			"syslog"		},
-[104] = { 0,	NF,		SEN(getgid),			"getgid"		},
+[104] = { 0,	PU|NF,		SEN(getgid),			"getgid"		},
 [105] = { 1,	0,		SEN(setuid),			"setuid"		},
 [106] = { 1,	0,		SEN(setgid),			"setgid"		},
-[107] = { 0,	NF,		SEN(geteuid),			"geteuid"		},
-[108] = { 0,	NF,		SEN(getegid),			"getegid"		},
+[107] = { 0,	PU|NF,		SEN(geteuid),			"geteuid"		},
+[108] = { 0,	PU|NF,		SEN(getegid),			"getegid"		},
 [109] = { 2,	0,		SEN(setpgid),			"setpgid"		},
-[110] = { 0,	NF,		SEN(getppid),			"getppid"		},
-[111] = { 0,	0,		SEN(getpgrp),			"getpgrp"		},
+[110] = { 0,	PU|NF,		SEN(getppid),			"getppid"		},
+[111] = { 0,	PU|NF,		SEN(getpgrp),			"getpgrp"		},
 [112] = { 0,	0,		SEN(setsid),			"setsid"		},
 [113] = { 2,	0,		SEN(setreuid),			"setreuid"		},
 [114] = { 2,	0,		SEN(setregid),			"setregid"		},
@@ -184,7 +184,7 @@
 [183] = { 5,	0,		SEN(afs_syscall),		"afs_syscall"		},
 [184] = { 3,	0,		SEN(tuxcall),			"tuxcall"		},
 [185] = { 3,	0,		SEN(security),			"security"		},
-[186] = { 0,	NF,		SEN(gettid),			"gettid"		},
+[186] = { 0,	PU|NF,		SEN(gettid),			"gettid"		},
 [187] = { 3,	TD,		SEN(readahead),			"readahead"		},
 [188] = { 5,	TF,		SEN(setxattr),			"setxattr"		},
 [189] = { 5,	TF,		SEN(setxattr),			"lsetxattr"		},
@@ -238,12 +238,12 @@
 [237] = { 6,	TM,		SEN(mbind),			"mbind"			},
 [238] = { 3,	TM,		SEN(set_mempolicy),		"set_mempolicy"		},
 [239] = { 5,	TM,		SEN(get_mempolicy),		"get_mempolicy"		},
-[240] = { 4,	0,		SEN(mq_open),			"mq_open"		},
+[240] = { 4,	TD,		SEN(mq_open),			"mq_open"		},
 [241] = { 1,	0,		SEN(mq_unlink),			"mq_unlink"		},
-[242] = { 5,	0,		SEN(mq_timedsend),		"mq_timedsend"		},
-[243] = { 5,	0,		SEN(mq_timedreceive),		"mq_timedreceive"	},
-[244] = { 2,	0,		SEN(mq_notify),			"mq_notify"		},
-[245] = { 3,	0,		SEN(mq_getsetattr),		"mq_getsetattr"		},
+[242] = { 5,	TD,		SEN(mq_timedsend),		"mq_timedsend"		},
+[243] = { 5,	TD,		SEN(mq_timedreceive),		"mq_timedreceive"	},
+[244] = { 2,	TD,		SEN(mq_notify),			"mq_notify"		},
+[245] = { 3,	TD,		SEN(mq_getsetattr),		"mq_getsetattr"		},
 [246] = { 4,	0,		SEN(kexec_load),		"kexec_load"		},
 [247] = { 5,	TP,		SEN(waitid),			"waitid"		},
 [248] = { 5,	0,		SEN(add_key),			"add_key"		},
