@@ -113,14 +113,14 @@
 [117] = { 3,	TF|TP|SE|SI,	SEN(execve),			"execve"		},
 [118] = { 1,	TP|SE,		SEN(exit),			"exit"			},
 [119] = { 1,	TP|SE,		SEN(exit),			"exit_group"		},
-[120] = { 0,	NF,		SEN(getpid),			"getpid"		},
+[120] = { 0,	PU|NF,		SEN(getpid),			"getpid"		},
 [121] = { 4,	TP,		SEN(wait4),			"wait4"			},
 [122] = { 5,	TP,		SEN(waitid),			"waitid"		},
 [123] = { 2,	TS,		SEN(kill),			"kill"			},
 [124] = { 2,	TS,		SEN(kill),			"tkill"			},
 [125] = { 3,	TS,		SEN(tgkill),			"tgkill"		},
 [126] = { 1,	0,		SEN(set_tid_address),		"set_tid_address"	},
-[127] = { 0,	NF,		SEN(gettid),			"gettid"		},
+[127] = { 0,	PU|NF,		SEN(gettid),			"gettid"		},
 [128] = { 0,	0,		SEN(setsid),			"setsid"		},
 [129] = { 1,	0,		SEN(getsid),			"getsid"		},
 [130] = { 5,	0,		SEN(prctl),			"prctl"			},
@@ -130,11 +130,11 @@
 [134] = { 3,	0,		SEN(setitimer),			"setitimer"		},
 [135] = { 2,	0,		SEN(getitimer),			"getitimer"		},
 [136] = { 1,	0,		SEN(setuid),			"setuid"		},
-[137] = { 0,	NF,		SEN(getuid),			"getuid"		},
+[137] = { 0,	PU|NF,		SEN(getuid),			"getuid"		},
 [138] = { 1,	0,		SEN(setgid),			"setgid"		},
-[139] = { 0,	NF,		SEN(getgid),			"getgid"		},
-[140] = { 0,	NF,		SEN(geteuid),			"geteuid"		},
-[141] = { 0,	NF,		SEN(getegid),			"getegid"		},
+[139] = { 0,	PU|NF,		SEN(getgid),			"getgid"		},
+[140] = { 0,	PU|NF,		SEN(geteuid),			"geteuid"		},
+[141] = { 0,	PU|NF,		SEN(getegid),			"getegid"		},
 [142] = { 2,	0,		SEN(setreuid),			"setreuid"		},
 [143] = { 2,	0,		SEN(setregid),			"setregid"		},
 [144] = { 3,	0,		SEN(setresuid),			"setresuid"		},
@@ -143,8 +143,8 @@
 [147] = { 3,	0,		SEN(getresgid),			"getresgid"		},
 [148] = { 2,	0,		SEN(setpgid),			"setpgid"		},
 [149] = { 1,	0,		SEN(getpgid),			"getpgid"		},
-[150] = { 0,	NF,		SEN(getppid),			"getppid"		},
-[151] = { 0,	0,		SEN(getpgrp),			"getpgrp"		},
+[150] = { 0,	PU|NF,		SEN(getppid),			"getppid"		},
+[151] = { 0,	PU|NF,		SEN(getpgrp),			"getpgrp"		},
 [152 ... 153] = { },
 [154] = { 1,	0,		SEN(times),			"times"			},
 [155] = { 1,	TF,		SEN(acct),			"acct"			},
@@ -222,12 +222,12 @@
 [229] = { 4,	TS,		SEN(rt_sigtimedwait),		"rt_sigtimedwait"	},
 [230] = { 3,	TS,		SEN(rt_sigqueueinfo),		"rt_sigqueueinfo"	},
 [231] = { 2,	TS,		SEN(rt_sigsuspend),		"rt_sigsuspend"		},
-[232] = { 4,	0,		SEN(mq_open),			"mq_open"		},
+[232] = { 4,	TD,		SEN(mq_open),			"mq_open"		},
 [233] = { 1,	0,		SEN(mq_unlink),			"mq_unlink"		},
-[234] = { 5,	0,		SEN(mq_timedsend),		"mq_timedsend"		},
-[235] = { 5,	0,		SEN(mq_timedreceive),		"mq_timedreceive"	},
-[236] = { 2,	0,		SEN(mq_notify),			"mq_notify"		},
-[237] = { 3,	0,		SEN(mq_getsetattr),		"mq_getsetattr"		},
+[234] = { 5,	TD,		SEN(mq_timedsend),		"mq_timedsend"		},
+[235] = { 5,	TD,		SEN(mq_timedreceive),		"mq_timedreceive"	},
+[236] = { 2,	TD,		SEN(mq_notify),			"mq_notify"		},
+[237] = { 3,	TD,		SEN(mq_getsetattr),		"mq_getsetattr"		},
 [238] = { },
 [239] = { 2,	TM,		SEN(io_setup),			"io_setup"		},
 [240] = { 1,	TM,		SEN(io_destroy),		"io_destroy"		},
