@@ -2,6 +2,7 @@
 #
 # Copyright (c) 2015 Elvira Khabirova <lineprinter0@gmail.com>
 # Copyright (c) 2015 Dmitry V. Levin <ldv@altlinux.org>
+# Copyright (c) 2015-2018 The strace developers.
 # All rights reserved.
 #
 # Redistribution and use in source and binary forms, with or without
@@ -27,6 +28,7 @@
 # THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 mpers_name="$1"; shift
+mpers_cc_flags="$1"; shift
 size="$(printf %s "$mpers_name" |tr -cd '[0-9]')"
 [ "$size" -gt 0 ]
 
@@ -56,7 +58,7 @@ typedef struct {
 		long long sll __attribute__((__aligned__(8)));
 		unsigned long long ull;
 		unsigned long ul;
-		long asl[3];
+		long asl[3][5][7];
 		char f;
 		/* unsigned char mpers_end_filler_4[7]; */
 	} s;
@@ -68,20 +70,24 @@ typedef struct {
 		unsigned long ul;
 		int si;
 		unsigned ui;
-		short ss;
-		unsigned short us;
+		short ss[7][9];
+		unsigned short us[4];
 		char sc;
 		unsigned char uc;
-	} u[3];
+	} u[3][2];
 	short f[0];
 } sample_struct;
 #include MPERS_DEFS
 EOF
 
 expected="$mpers_dir/sample.expected"
+mpers_ptr_t="uint${size}_t"
 cat > "$expected" <<EOF
 #include <inttypes.h>
-typedef uint${size}_t mpers_ptr_t;
+#ifndef mpers_ptr_t_is_${mpers_ptr_t}
+typedef ${mpers_ptr_t} mpers_ptr_t;
+#define mpers_ptr_t_is_${mpers_ptr_t}
+#endif
 typedef
 struct {
 struct {
@@ -99,7 +105,7 @@ unsigned char mpers_filler_3[6];
 int64_t sll;
 uint64_t ull;
 uint${size}_t ul;
-int${size}_t asl[3];
+int${size}_t asl[3][5][7];
 char f;
 unsigned char mpers_end_filler_4[7];
 } ATTRIBUTE_PACKED s;
@@ -111,11 +117,11 @@ int${size}_t sl;
 uint${size}_t ul;
 int32_t si;
 uint32_t ui;
-int16_t ss;
-uint16_t us;
+int16_t ss[7][9];
+uint16_t us[4];
 char sc;
 unsigned char uc;
-} u[3];
+} u[3][2];
 int16_t f[0];
 } ATTRIBUTE_PACKED ${mpers_name}_sample_struct;
 #define MPERS_${mpers_name}_sample_struct ${mpers_name}_sample_struct
@@ -123,5 +129,5 @@ EOF
 
 CFLAGS="$CPPFLAGS -I${srcdir} -DMPERS_IS_${mpers_name}" \
 CPPFLAGS="$CPPFLAGS -I${srcdir} -DIN_MPERS -DMPERS_IS_${mpers_name}" \
-"$mpers_sh" "-$mpers_name" "$sample"
+"$mpers_sh" "$mpers_name" "$mpers_cc_flags" "$sample"
 cmp "$expected" "$mpers_dir"/sample_struct.h > /dev/null
